#!/usr/bin/env python

#############################[ Parameters you should change if install failed ]#########################################
# python_dir should point to the directory where Python header files may be found.. (Inside this dir you should have a Python.h)
python_dir="/usr/include/python2.2"
#############################[ End of parameters that can be changed ]##################################################

try:
    import sys,commands,traceback,os
    from distutils import sysconfig
    from distutils.core import setup,Extension
    from distutils.command.build_ext import build_ext
    from distutils.errors import CCompilerError    
    from string import *
except:
    traceback.print_exc()
    print "Unable to import python distutils."
    print "You may want to install the python-dev package on your distribution."
    sys.exit(1)

############## Init some vars
extra_compile_args = []
extra_link_args = []
include_dirs = []
library_dirs = []
libraries = []
failedbuild = 0

if os.name not in ["nt","dos"]:                   # *NIX systems
    print "#################################### Check Python"
    if int(sys.version[0]) < 2:             # check py version and Python include dir
        print "--- WARNING ---\nYou need Python version 2.x or more. If something doesn't work or install fails, please update Python."
    if python_dir[-1] != '/': python_dir=python_dir+'/'
    if not os.path.exists(python_dir+"Python.h"):
        python_dir=sysconfig.get_python_inc() # get help from distutils sysconfig submodule
        if python_dir[-1] != '/': python_dir=python_dir+'/'
        if not os.path.exists(python_dir+"Python.h"): # give up...
            print "--- WARNING ---\nUnable to find python development files. Make sure you have the python-devel package for your GNU/Linux distribution installed."
            print "If that didn't help, you may need to locate the place where the python C headers are stored and change the line in setup.py where \"/usr/include/python2.2\" is found. (on the beginning of setup.py)"
    include_dirs.append(python_dir)        
    print "Checked."

    print "#################################### Check wxWindows"
    IMagCLib = None
    IMagCFlag = None
    wxFound = 0
    try:
        from commands import getstatusoutput,getoutput
        IMagCFlag=getstatusoutput("wx-config --cppflags")
        if not IMagCFlag[0]:
            IMagCFlag = IMagCFlag[1]
            if find(IMagCFlag,"-I") != -1:
                IMagCFlag=replace(IMagCFlag,"\n"," ")
                IMagCFlag=split(IMagCFlag,' ')
                IMagCLib=getoutput("wx-config --ldflags --libs")
                IMagCLib=replace(IMagCLib,"\n"," ")
                IMagCLib=split(IMagCLib,' ')
                wxFound = 1
        else:
            print "--- ERROR ---\nUnable to find \"wx-config\". Are you sure you have wxWindows/wxGTK and it's development files installed correctly ?"
    except:
        traceback.print_exc()
        print "Please report the above traceback to \"nieder@mail.ru\""
    if not wxFound:
        sys.exit(1)
        
    libraries=[]  
    for cf in IMagCFlag:
        cf=strip(cf)
        if not cf: continue
        extra_compile_args.append(cf)
    for cf in IMagCLib:
        cf=strip(cf)
        if not cf: continue
        extra_link_args.append(cf)
        
    print "Found the following arguments:"
    print "extra_compile_args",extra_compile_args
    print "extra_link_args",extra_link_args

    print "Checked."
    
else:                                   # WINDOWS SYSTEMS
    import py2exe
    wxWinPath = "C:\\wxWindows-2.4.1\\" # set this to the path of your windows wxWindows source installation
    library_dirs=[wxWinPath + "lib",wxWinPath +"contrib\\lib" ]
    include_dirs=["c:\\python23\\include",wxWinPath +"include",wxWinPath +"\\contrib\\include",wxWinPath +"\\lib\\msw"]
    libraries = ["wxmsw","png","zlib","jpeg","tiff"]   # you may want to try "qt" if your QT has no multithreading support
    libraries += ["kernel32","user32","gdi32","winspool","comdlg32","advapi32","shell32","ole32","oleaut32","uuid","odbc32","odbccp32","comctl32","rpcrt4","wsock32","winmm"]
    extra_compile_args=extra_compile_args+["-DNDEBUG","-DWIN32","-D_WINDOWS","-D__WINDOWS__","-D__WXMSW__","-D__WIN95__","-D__WIN32__","-DWINVER=0x0400","-DSTRICT"]

class fallible_build_ext(build_ext):
    """the purpose of this class is to know when a compile error ocurred """
    def run(self):
        try:
            build_ext.run(self)
        except CCompilerError:
            traceback.print_exc()
            failedbuild=1
            print """
Unable to compile and install the C++ extension module.
It is strongly recommended that you install the python-dev (python-devel on some distributions) package for your GNU/Linux distribution, and then try \"python setup.py install\" again.
Please refer to http://imgseek.sf.net/requirements.html for more instructions.
"""
try:
    print "#################################### Installing"
    from imgSeekLiteLib import __version__
    setup(name="imgSeekLite",
          version=__version__,
          description="imgSeek photo collection manager and viewer with content-based query. [LITE version]",
          long_description ="""imgSeek is a photo collection manager and viewer with content-based search and many other features. The query is expressed either as a rough sketch painted by the user or as another image you supply (or an image in your collection).""",
          author="Ricardo Niederberger Cabral",
          author_email="nieder|at|mail.ru",
          url="http://imgseek.sourceforge.net/lite/",
          platforms = ['Linux','Windows'],
          cmdclass = { 'build_ext': fallible_build_ext},                
          license = 'GPL2',
          data_files = [("share/imgSeekLite",["imgSeekLiteLib/resources/wizard.png",
                                              "imgSeekLiteLib/resources/eraser.png",
                                              "imgSeekLiteLib/resources/find.png",                                              
                                              "imgSeekLiteLib/resources/imgSeekLite.ico"
                                              ])],
          packages=['imgSeekLiteLib'],
          scripts= ['imgSeekLite'],
          ext_modules = [
            Extension("imgSeekLiteLib._imgdb",["imgSeekLiteLib/imgdb.cpp"],
                      include_dirs = include_dirs,
                      library_dirs = library_dirs,
                      extra_compile_args=extra_compile_args,
                      extra_link_args=extra_link_args,
                      libraries = libraries
                     )]
         )

except:
    traceback.print_exc()
    print "An unexpected error occurred during setup.\nPlease help development by reporting this bug to \"imgseek-devel@lists.sourceforge.net\"."
    print "You have to become root before installing imgSeek. (type \"su\" and then enter your root password)"

if failedbuild:
      print """Warning:\n
Unable to compile and install the C++ module extension.
It is strongly recommended that you install the python-dev (python-devel on some distributions) package for your GNU/Linux distribution, and then try \"python setup.py install\" again.
Also make sure you either have QT development files installed (package qt-3.x-devel on some distributions) or ImageMagick libraries and development files installed. (recommended)
Please refer to http://imgseek.sf.net/requirements.html for more instructions.
"""
else:
    print "\nimgSeekLite install complete.\nRun it with \"imgSeekLite\"\n"
